#
# spec file for package prelude-manager
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:             prelude-manager
Version:          3.0.0
Release:          1.1
Summary:          Bus communication for all Prelude modules
License:          GPL-3.0+
Group:            Applications/Internet
Url:              https://www.prelude-siem.org
Source0:          https://www.prelude-siem.org/pkg/src/3.0.0/%{name}-%{version}.tar.gz
Source1:          prelude-manager.service
Source2:          prelude-manager.run
Patch0:           prelude-manager-run-dir.patch
BuildRequires:    libgnutls-devel 
BuildRequires:    pkg-config
BuildRequires:    libprelude-devel
BuildRequires:    libpreludedb-devel 
BuildRequires:    libxml2-devel
BuildRequires:    systemd
BuildRequires:    tcpd-devel
%{?systemd_requires}

%description
Prelude Manager is a high availability server that
accepts secured connections from distributed sensors
and saves received events to a media specified by the user
(database, log file, mail etc.). The server schedules and
establishes the priorities of treatment according to the
critical character and the source of the alerts.

%package devel
Summary:  Libraries, include files for Prelude Manager
Group:    Development/Libraries/C and C++
Requires: %{name} = %{version}-%{release}
Requires: libpreludedb-devel

%description devel
Header files and libraries for prelude-manager development.

%package db-plugin
Summary:  Database report plugin for Prelude Manager
Group:    Applications/Internet
Requires: %{name} = %{version}-%{release}

%description db-plugin
This plugin allows prelude-manager to write to database.

%package xml-plugin
Summary: XML report plugin for Prelude Manager
Group:   Applications/Internet
Requires: %{name} = %{version}-%{release}

%description xml-plugin
This plugin adds XML logging capabilities to prelude-manager.

%package smtp-plugin
Summary: SMTP alert plugin for Prelude Manager
Group:   Applications/Internet
Requires: %{name} = %{version}-%{release}

%description smtp-plugin
This plugin adds alerting by email capabilities to prelude-manager

%prep
%setup -q
%patch0 -p0

%build
%configure --with-libwrap
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-%{version}
mkdir -p %{buildroot}/%{_localstatedir}/spool/prelude/%{name}/
make install DESTDIR=%{buildroot} INSTALL="%{__install} -c -p"
rm -f %{buildroot}/%{_libdir}/%{name}/reports/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/filters/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/decodes/*.la
rm -f %{buildroot}/%{_defaultdocdir}/../%{name}/smtp/template.example
mkdir -p %{buildroot}/%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
install -d -m 0755 %{buildroot}/%{_tmpfilesdir}
install -m 0644 %{SOURCE2} %{buildroot}/%{_tmpfilesdir}/%{name}.conf
rm -rf %{buildroot}/%{_localstatedir}/run/%{name}
install -D -m 444 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

%pre
%service_add_pre %{name}.service

%post
/sbin/ldconfig
/usr/bin/systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
/sbin/ldconfig
%service_del_postun %{name}.service

%files
%defattr(-,root,root,-)
%doc COPYING
%attr(0750,-,-) %dir %{_sysconfdir}/%{name}/
%config(noreplace) %attr(0640,-,-) %{_sysconfdir}/%{name}/%{name}.conf
%{_bindir}/%{name}
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/filters/
%{_libdir}/%{name}/filters/*.so
%dir %{_libdir}/%{name}/reports/
%{_libdir}/%{name}/reports/debug.so
%{_libdir}/%{name}/reports/textmod.so
%dir %{_libdir}/%{name}/decodes/
%{_libdir}/%{name}/decodes/*.so
%attr(0711,-,-) %dir %{_localstatedir}/spool/prelude
%attr(0750,-,-) %dir %{_localstatedir}/spool/prelude/%{name}/
%attr(0750,-,-) %dir %{_datadir}/%{name}/
%attr(0644,-,-) %{_mandir}/man1/%{name}.1.gz
%{_sbindir}/rc%{name}
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service

%files db-plugin
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/reports
%{_libdir}/%{name}/reports/db.so

%files xml-plugin
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/reports
%{_libdir}/%{name}/reports/xmlmod.so
%attr(0750,root,root) %dir %{_datadir}/%{name}/xmlmod/
%{_datadir}/%{name}/xmlmod/*

%files smtp-plugin
%defattr(-,root,root,-)
%doc %attr(0644,root,root) plugins/reports/smtp/template.example
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/reports
%{_libdir}/%{name}/reports/smtp.so

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/

%changelog
* Thu Sep 15 2016 thomas.andrejak@gmail.com
- Update licence from GPL-2.0+ to GPL-3.0+ to include libmissing
* Sun Sep  4 2016 thomas.andrejak@gmail.com
- Remove Selinux since it should be directly in Security:SELinux
- Fix declaration of "%%dir %%{_datadir}/%%{name}" two times
* Sun Aug 28 2016 jengelh@inai.de
- Re-set RPM groups to match SUSE categories
- Ensure all directories are owned
- Remove undesirable manual requires on shared libraries
* Tue May  3 2016 thomas.andrejak@gmail.com
- Initial import
- Generate the plugins:
  * DB (database)
  * SMTP
  * XML
- Add systemd files because it is a daemon.
- Also package SELinux files.
